@@ -1,6 +1,5 @@
 #!/usr/bin/env perl
 
-use 5.018;
 use strict;
 use warnings;
 
@@ -14,9 +13,9 @@ my($sth) = $dbh -> foreign_key_info(undef, undef, 'one', undef, undef, 'two');
 
 if ($sth)
 {
-	say Dumper($sth->fetchall_hashref(['PKTABLE_NAME']) );
+	print Dumper($sth->fetchall_hashref(['PKTABLE_NAME']) );
 }
 else
 {
-	say 'foreign_key_info() returned undef';
+	print "foreign_key_info() returned undef\n";
 }
